==> training-facade-3.2.2.4-sources.jar: cn/smarthse/radiationTraining/modules/wqxx/model/vo/answerExercise/SUserQuestionVo.java <==
package cn.smarthse.radiationTraining.modules.wqxx.model.vo.answerExercise;

import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.EqualsAndHashCode;

import java.io.Serializable;

/**
 * 试题vo
 * @author chuhaiyang
 */
@Data
@EqualsAndHashCode(callSuper = false)
public class SUserQuestionVo implements Serializable {

    private static final long serialVersionUID = 9134439922616197844L;
    
    @ApiModelProperty("用户试卷对应试题id")
    private Long id;

    /**
     * 试题id
     */
    @ApiModelProperty("试题id")
    private Long questionId;

    /**
    * 试题类别（1-单选题；2-多选题；3-填空题；4-判断题）
    */
    @ApiModelProperty("试题类别（1-单选题；2-多选题；3-填空题；4-判断题）")
    private Integer type;
    
    /**
    * 题干
    */
    @ApiModelProperty("题干")
    private String stem;

    
    /**
    * 选项A(对)
    */
    @ApiModelProperty("选项A(对)")
    private String optionA;

    /**
    * 选项B(错)
    */
    @ApiModelProperty("选项B(错)")
    private String optionB;

    /**
    * 选项C
    */
    @ApiModelProperty("选项C")
    private String optionC;

    /**
    * 选项D
    */
    @ApiModelProperty("选项D")
    private String optionD;

    /**
    * 选项E
    */
    @ApiModelProperty("选项E")
    private String optionE;

    /**
    * 选项F
    */
    @ApiModelProperty("选项F")
    private String optionF;

    /**
    * 选项G
    */
    @ApiModelProperty("选项G")
    private String optionG;

    /**
    * 正确答案（多选：AB）
    */
    @ApiModelProperty("正确答案（多选：AB）")
    private String answer;

    /**
    * 解析
    */
    @ApiModelProperty("解析")
    private String analysis;

    @ApiModelProperty(value = "用户答案")
    private String userAnswer;

    /**
     * 结果判定(对：true；错：false)
     */
    @ApiModelProperty("结果判定(对：true；错：false)")
    private Boolean result;
}

==> training-facade-4.0.0-sources.jar: cn/smarthse/radiationTraining/modules/wqxx/model/vo/answerExercise/SUserQuestionVo.java <==
package cn.smarthse.radiationTraining.modules.wqxx.model.vo.answerExercise;

import lombok.Data;
import lombok.EqualsAndHashCode;

import java.io.Serializable;

/**
 * 试题vo
 * @author chuhaiyang
 */
@Data
@EqualsAndHashCode(callSuper = false)
public class SUserQuestionVo implements Serializable {

    private static final long serialVersionUID = 9134439922616197844L;
    
    //@ApiModelProperty("用户试卷对应试题id")
    private Long id;

    /**
     * 试题id
     */
    //@ApiModelProperty("试题id")
    private Long questionId;

    /**
    * 试题类别（1-单选题；2-多选题；3-填空题；4-判断题）
    */
    //@ApiModelProperty("试题类别（1-单选题；2-多选题；3-填空题；4-判断题）")
    private Integer type;
    
    /**
    * 题干
    */
    //@ApiModelProperty("题干")
    private String stem;

    
    /**
    * 选项A(对)
    */
    //@ApiModelProperty("选项A(对)")
    private String optionA;

    /**
    * 选项B(错)
    */
    //@ApiModelProperty("选项B(错)")
    private String optionB;

    /**
    * 选项C
    */
    //@ApiModelProperty("选项C")
    private String optionC;

    /**
    * 选项D
    */
    //@ApiModelProperty("选项D")
    private String optionD;

    /**
    * 选项E
    */
    //@ApiModelProperty("选项E")
    private String optionE;

    /**
    * 选项F
    */
    //@ApiModelProperty("选项F")
    private String optionF;

    /**
    * 选项G
    */
    //@ApiModelProperty("选项G")
    private String optionG;

    /**
    * 正确答案（多选：AB）
    */
    //@ApiModelProperty("正确答案（多选：AB）")
    private String answer;

    /**
    * 解析
    */
    //@ApiModelProperty("解析")
    private String analysis;

    //@ApiModelProperty(value = "用户答案")
    private String userAnswer;

    /**
     * 结果判定(对：true；错：false)
     */
    //@ApiModelProperty("结果判定(对：true；错：false)")
    private Boolean result;
}
